/*
 * pic32_additions.c
 *
 * This library adds a few PIC32-related functions for doing I/O.  They
 * are intended to only be used with the MPLAB simulator (the actual PIC
 * might require extra lines of code).  The internals of these functions 
 * will become clear as the course progresses.  Further information can
 * be found in the references below.
 *
 * PIC32MX Family Reference Manual, Section 21. UART
 * C32 C Lib Guide, p. 30 (found under MPLAB's Help->Topics...)
 * 
 * HISTORY:
 *
 * 1/4/2011  Created by Nelson Rosa
 *
 */

#include <stdio.h>      // input/output, like scanf and printf
#include <plib.h>		// generic PIC peripheral functionality
#include <p32xxxx.h>	// PIC32 chip-specific functionality

#define NULCH '\0'
#define NEWLINE 0xA

// the canned inputs for this example
char *myinputs[] = {
// good input $$ increases
"100 2.0 5",
// good input $$ decreases
"100 0.5 5",
// bad input
"-10 1.2 5"
};

/* initUart1
*
* This initializes UART1 using PIC32-specific syntax.
*/

void initUart1(void)
{
	U1MODEbits.UARTEN = 1;
	U1STAbits.UTXEN = 1;
	U1STAbits.URXEN = 1;
}

/* _mon_putc
*
* This function redirects stdout to write to UART1.
*/

void _mon_putc (char c)
{
	while (U1STAbits.UTXBF);
	U1TXREG = c;
}

/* _mon_getc
*
* This function redirects stdin to read from an array
*/

int _mon_getc(int callback)
{
   	static int i = 0, j = 0;
   	int c;
	
	if(myinputs[i] != NULL) {
		c = myinputs[i][j];
		j++;
		if(c == NULCH) {
			c = NEWLINE;
			j = 0;
			i++;
		}	

		return c;
	}

	return EOF;	
}
